# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EgressMatrixCellArgs', 'EgressMatrixCell']

@pulumi.input_type
class EgressMatrixCellArgs:
    def __init__(__self__, *,
                 destination_sgt_id: pulumi.Input[builtins.str],
                 source_sgt_id: pulumi.Input[builtins.str],
                 default_rule: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 matrix_cell_status: Optional[pulumi.Input[builtins.str]] = None,
                 sgacls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a EgressMatrixCell resource.
        :param pulumi.Input[builtins.str] destination_sgt_id: Destination Trustsec Security Group ID
        :param pulumi.Input[builtins.str] source_sgt_id: Source Trustsec Security Group ID
        :param pulumi.Input[builtins.str] default_rule: Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] matrix_cell_status: Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] sgacls: List of TrustSec Security Groups ACLs
        """
        pulumi.set(__self__, "destination_sgt_id", destination_sgt_id)
        pulumi.set(__self__, "source_sgt_id", source_sgt_id)
        if default_rule is not None:
            pulumi.set(__self__, "default_rule", default_rule)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if matrix_cell_status is not None:
            pulumi.set(__self__, "matrix_cell_status", matrix_cell_status)
        if sgacls is not None:
            pulumi.set(__self__, "sgacls", sgacls)

    @property
    @pulumi.getter(name="destinationSgtId")
    def destination_sgt_id(self) -> pulumi.Input[builtins.str]:
        """
        Destination Trustsec Security Group ID
        """
        return pulumi.get(self, "destination_sgt_id")

    @destination_sgt_id.setter
    def destination_sgt_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "destination_sgt_id", value)

    @property
    @pulumi.getter(name="sourceSgtId")
    def source_sgt_id(self) -> pulumi.Input[builtins.str]:
        """
        Source Trustsec Security Group ID
        """
        return pulumi.get(self, "source_sgt_id")

    @source_sgt_id.setter
    def source_sgt_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "source_sgt_id", value)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        """
        return pulumi.get(self, "default_rule")

    @default_rule.setter
    def default_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_rule", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="matrixCellStatus")
    def matrix_cell_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        """
        return pulumi.get(self, "matrix_cell_status")

    @matrix_cell_status.setter
    def matrix_cell_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "matrix_cell_status", value)

    @property
    @pulumi.getter
    def sgacls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of TrustSec Security Groups ACLs
        """
        return pulumi.get(self, "sgacls")

    @sgacls.setter
    def sgacls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "sgacls", value)


@pulumi.input_type
class _EgressMatrixCellState:
    def __init__(__self__, *,
                 default_rule: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
                 matrix_cell_status: Optional[pulumi.Input[builtins.str]] = None,
                 sgacls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 source_sgt_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering EgressMatrixCell resources.
        :param pulumi.Input[builtins.str] default_rule: Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] destination_sgt_id: Destination Trustsec Security Group ID
        :param pulumi.Input[builtins.str] matrix_cell_status: Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] sgacls: List of TrustSec Security Groups ACLs
        :param pulumi.Input[builtins.str] source_sgt_id: Source Trustsec Security Group ID
        """
        if default_rule is not None:
            pulumi.set(__self__, "default_rule", default_rule)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if destination_sgt_id is not None:
            pulumi.set(__self__, "destination_sgt_id", destination_sgt_id)
        if matrix_cell_status is not None:
            pulumi.set(__self__, "matrix_cell_status", matrix_cell_status)
        if sgacls is not None:
            pulumi.set(__self__, "sgacls", sgacls)
        if source_sgt_id is not None:
            pulumi.set(__self__, "source_sgt_id", source_sgt_id)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        """
        return pulumi.get(self, "default_rule")

    @default_rule.setter
    def default_rule(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "default_rule", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="destinationSgtId")
    def destination_sgt_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Destination Trustsec Security Group ID
        """
        return pulumi.get(self, "destination_sgt_id")

    @destination_sgt_id.setter
    def destination_sgt_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "destination_sgt_id", value)

    @property
    @pulumi.getter(name="matrixCellStatus")
    def matrix_cell_status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        """
        return pulumi.get(self, "matrix_cell_status")

    @matrix_cell_status.setter
    def matrix_cell_status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "matrix_cell_status", value)

    @property
    @pulumi.getter
    def sgacls(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        List of TrustSec Security Groups ACLs
        """
        return pulumi.get(self, "sgacls")

    @sgacls.setter
    def sgacls(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "sgacls", value)

    @property
    @pulumi.getter(name="sourceSgtId")
    def source_sgt_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Source Trustsec Security Group ID
        """
        return pulumi.get(self, "source_sgt_id")

    @source_sgt_id.setter
    def source_sgt_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "source_sgt_id", value)


class EgressMatrixCell(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_rule: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
                 matrix_cell_status: Optional[pulumi.Input[builtins.str]] = None,
                 sgacls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 source_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        This resource can manage a TrustSec Egress Matrix Cell.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.EgressMatrixCell("example",
            description="EgressMatrixCell Description",
            default_rule="NONE",
            matrix_cell_status="ENABLED",
            sgacls=["26b76b10-66e6-11ee-9cc1-9eb2a3ecc82a, 9d64dcd0-6384-11ee-9cc1-9eb2a3ecc82a"],
            source_sgt_id="93c66ed0-8c01-11e6-996c-525400b48521",
            destination_sgt_id="93e1bf00-8c01-11e6-996c-525400b48521")
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/egressMatrixCell:EgressMatrixCell example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] default_rule: Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] destination_sgt_id: Destination Trustsec Security Group ID
        :param pulumi.Input[builtins.str] matrix_cell_status: Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] sgacls: List of TrustSec Security Groups ACLs
        :param pulumi.Input[builtins.str] source_sgt_id: Source Trustsec Security Group ID
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EgressMatrixCellArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TrustSec Egress Matrix Cell.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.trustsec.EgressMatrixCell("example",
            description="EgressMatrixCell Description",
            default_rule="NONE",
            matrix_cell_status="ENABLED",
            sgacls=["26b76b10-66e6-11ee-9cc1-9eb2a3ecc82a, 9d64dcd0-6384-11ee-9cc1-9eb2a3ecc82a"],
            source_sgt_id="93c66ed0-8c01-11e6-996c-525400b48521",
            destination_sgt_id="93e1bf00-8c01-11e6-996c-525400b48521")
        ```

        ## Import

        ```sh
        $ pulumi import ise:trustsec/egressMatrixCell:EgressMatrixCell example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param EgressMatrixCellArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EgressMatrixCellArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 default_rule: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 destination_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
                 matrix_cell_status: Optional[pulumi.Input[builtins.str]] = None,
                 sgacls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 source_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EgressMatrixCellArgs.__new__(EgressMatrixCellArgs)

            __props__.__dict__["default_rule"] = default_rule
            __props__.__dict__["description"] = description
            if destination_sgt_id is None and not opts.urn:
                raise TypeError("Missing required property 'destination_sgt_id'")
            __props__.__dict__["destination_sgt_id"] = destination_sgt_id
            __props__.__dict__["matrix_cell_status"] = matrix_cell_status
            __props__.__dict__["sgacls"] = sgacls
            if source_sgt_id is None and not opts.urn:
                raise TypeError("Missing required property 'source_sgt_id'")
            __props__.__dict__["source_sgt_id"] = source_sgt_id
        super(EgressMatrixCell, __self__).__init__(
            'ise:trustsec/egressMatrixCell:EgressMatrixCell',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            default_rule: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            destination_sgt_id: Optional[pulumi.Input[builtins.str]] = None,
            matrix_cell_status: Optional[pulumi.Input[builtins.str]] = None,
            sgacls: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            source_sgt_id: Optional[pulumi.Input[builtins.str]] = None) -> 'EgressMatrixCell':
        """
        Get an existing EgressMatrixCell resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] default_rule: Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] destination_sgt_id: Destination Trustsec Security Group ID
        :param pulumi.Input[builtins.str] matrix_cell_status: Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] sgacls: List of TrustSec Security Groups ACLs
        :param pulumi.Input[builtins.str] source_sgt_id: Source Trustsec Security Group ID
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EgressMatrixCellState.__new__(_EgressMatrixCellState)

        __props__.__dict__["default_rule"] = default_rule
        __props__.__dict__["description"] = description
        __props__.__dict__["destination_sgt_id"] = destination_sgt_id
        __props__.__dict__["matrix_cell_status"] = matrix_cell_status
        __props__.__dict__["sgacls"] = sgacls
        __props__.__dict__["source_sgt_id"] = source_sgt_id
        return EgressMatrixCell(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> pulumi.Output[builtins.str]:
        """
        Can be used only if sgacls not specified. - Choices: `NONE`, `DENY_IP`, `PERMIT_IP` - Default value: `NONE`
        """
        return pulumi.get(self, "default_rule")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="destinationSgtId")
    def destination_sgt_id(self) -> pulumi.Output[builtins.str]:
        """
        Destination Trustsec Security Group ID
        """
        return pulumi.get(self, "destination_sgt_id")

    @property
    @pulumi.getter(name="matrixCellStatus")
    def matrix_cell_status(self) -> pulumi.Output[builtins.str]:
        """
        Matrix Cell Status - Choices: `DISABLED`, `ENABLED`, `MONITOR` - Default value: `DISABLED`
        """
        return pulumi.get(self, "matrix_cell_status")

    @property
    @pulumi.getter
    def sgacls(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        List of TrustSec Security Groups ACLs
        """
        return pulumi.get(self, "sgacls")

    @property
    @pulumi.getter(name="sourceSgtId")
    def source_sgt_id(self) -> pulumi.Output[builtins.str]:
        """
        Source Trustsec Security Group ID
        """
        return pulumi.get(self, "source_sgt_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['TacacsCommandSetArgs', 'TacacsCommandSet']

@pulumi.input_type
class TacacsCommandSetArgs:
    def __init__(__self__, *,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permit_unmatched: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a TacacsCommandSet resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS command set
        :param pulumi.Input[builtins.bool] permit_unmatched: Permit unmatched commands - Default value: `false`
        """
        if commands is not None:
            pulumi.set(__self__, "commands", commands)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permit_unmatched is not None:
            pulumi.set(__self__, "permit_unmatched", permit_unmatched)

    @property
    @pulumi.getter
    def commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]]:
        return pulumi.get(self, "commands")

    @commands.setter
    def commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]]):
        pulumi.set(self, "commands", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the TACACS command set
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permitUnmatched")
    def permit_unmatched(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Permit unmatched commands - Default value: `false`
        """
        return pulumi.get(self, "permit_unmatched")

    @permit_unmatched.setter
    def permit_unmatched(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "permit_unmatched", value)


@pulumi.input_type
class _TacacsCommandSetState:
    def __init__(__self__, *,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permit_unmatched: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering TacacsCommandSet resources.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS command set
        :param pulumi.Input[builtins.bool] permit_unmatched: Permit unmatched commands - Default value: `false`
        """
        if commands is not None:
            pulumi.set(__self__, "commands", commands)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if permit_unmatched is not None:
            pulumi.set(__self__, "permit_unmatched", permit_unmatched)

    @property
    @pulumi.getter
    def commands(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]]:
        return pulumi.get(self, "commands")

    @commands.setter
    def commands(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['TacacsCommandSetCommandArgs']]]]):
        pulumi.set(self, "commands", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the TACACS command set
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="permitUnmatched")
    def permit_unmatched(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Permit unmatched commands - Default value: `false`
        """
        return pulumi.get(self, "permit_unmatched")

    @permit_unmatched.setter
    def permit_unmatched(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "permit_unmatched", value)


class TacacsCommandSet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsCommandSetCommandArgs', 'TacacsCommandSetCommandArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permit_unmatched: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        This resource can manage a TACACS Command Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.TacacsCommandSet("example",
            name="CommandSet1",
            description="My TACACS command set",
            permit_unmatched=True,
            commands=[{
                "grant": "PERMIT",
                "command": "show",
                "arguments": "",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:deviceadmin/tacacsCommandSet:TacacsCommandSet example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS command set
        :param pulumi.Input[builtins.bool] permit_unmatched: Permit unmatched commands - Default value: `false`
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[TacacsCommandSetArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a TACACS Command Set.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.deviceadmin.TacacsCommandSet("example",
            name="CommandSet1",
            description="My TACACS command set",
            permit_unmatched=True,
            commands=[{
                "grant": "PERMIT",
                "command": "show",
                "arguments": "",
            }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:deviceadmin/tacacsCommandSet:TacacsCommandSet example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param TacacsCommandSetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(TacacsCommandSetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 commands: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsCommandSetCommandArgs', 'TacacsCommandSetCommandArgsDict']]]]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 permit_unmatched: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = TacacsCommandSetArgs.__new__(TacacsCommandSetArgs)

            __props__.__dict__["commands"] = commands
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["permit_unmatched"] = permit_unmatched
        super(TacacsCommandSet, __self__).__init__(
            'ise:deviceadmin/tacacsCommandSet:TacacsCommandSet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            commands: Optional[pulumi.Input[Sequence[pulumi.Input[Union['TacacsCommandSetCommandArgs', 'TacacsCommandSetCommandArgsDict']]]]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            permit_unmatched: Optional[pulumi.Input[builtins.bool]] = None) -> 'TacacsCommandSet':
        """
        Get an existing TacacsCommandSet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: Description
        :param pulumi.Input[builtins.str] name: The name of the TACACS command set
        :param pulumi.Input[builtins.bool] permit_unmatched: Permit unmatched commands - Default value: `false`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _TacacsCommandSetState.__new__(_TacacsCommandSetState)

        __props__.__dict__["commands"] = commands
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["permit_unmatched"] = permit_unmatched
        return TacacsCommandSet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def commands(self) -> pulumi.Output[Optional[Sequence['outputs.TacacsCommandSetCommand']]]:
        return pulumi.get(self, "commands")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the TACACS command set
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="permitUnmatched")
    def permit_unmatched(self) -> pulumi.Output[builtins.bool]:
        """
        Permit unmatched commands - Default value: `false`
        """
        return pulumi.get(self, "permit_unmatched")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetEgressMatrixCellDefaultResult',
    'AwaitableGetEgressMatrixCellDefaultResult',
    'get_egress_matrix_cell_default',
    'get_egress_matrix_cell_default_output',
]

@pulumi.output_type
class GetEgressMatrixCellDefaultResult:
    """
    A collection of values returned by getEgressMatrixCellDefault.
    """
    def __init__(__self__, default_rule=None, description=None, id=None, matrix_cell_status=None, sgacls=None):
        if default_rule and not isinstance(default_rule, str):
            raise TypeError("Expected argument 'default_rule' to be a str")
        pulumi.set(__self__, "default_rule", default_rule)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if matrix_cell_status and not isinstance(matrix_cell_status, str):
            raise TypeError("Expected argument 'matrix_cell_status' to be a str")
        pulumi.set(__self__, "matrix_cell_status", matrix_cell_status)
        if sgacls and not isinstance(sgacls, list):
            raise TypeError("Expected argument 'sgacls' to be a list")
        pulumi.set(__self__, "sgacls", sgacls)

    @property
    @pulumi.getter(name="defaultRule")
    def default_rule(self) -> builtins.str:
        """
        Can be used only if sgacls not specified. Final Catch All Rule
        """
        return pulumi.get(self, "default_rule")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The id of the object
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="matrixCellStatus")
    def matrix_cell_status(self) -> builtins.str:
        """
        Matrix Cell Status
        """
        return pulumi.get(self, "matrix_cell_status")

    @property
    @pulumi.getter
    def sgacls(self) -> Sequence[builtins.str]:
        """
        List of TrustSec Security Groups ACLs
        """
        return pulumi.get(self, "sgacls")


class AwaitableGetEgressMatrixCellDefaultResult(GetEgressMatrixCellDefaultResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEgressMatrixCellDefaultResult(
            default_rule=self.default_rule,
            description=self.description,
            id=self.id,
            matrix_cell_status=self.matrix_cell_status,
            sgacls=self.sgacls)


def get_egress_matrix_cell_default(id: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEgressMatrixCellDefaultResult:
    """
    This data source can read the TrustSec Egress Matrix Cell Default.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_egress_matrix_cell_default(id="92c1a900-8c01-11e6-996c-525400b48521")
    ```


    :param builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ise:trustsec/getEgressMatrixCellDefault:getEgressMatrixCellDefault', __args__, opts=opts, typ=GetEgressMatrixCellDefaultResult).value

    return AwaitableGetEgressMatrixCellDefaultResult(
        default_rule=pulumi.get(__ret__, 'default_rule'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        matrix_cell_status=pulumi.get(__ret__, 'matrix_cell_status'),
        sgacls=pulumi.get(__ret__, 'sgacls'))
def get_egress_matrix_cell_default_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEgressMatrixCellDefaultResult]:
    """
    This data source can read the TrustSec Egress Matrix Cell Default.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ise as ise

    example = ise.trustsec.get_egress_matrix_cell_default(id="92c1a900-8c01-11e6-996c-525400b48521")
    ```


    :param builtins.str id: The id of the object
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ise:trustsec/getEgressMatrixCellDefault:getEgressMatrixCellDefault', __args__, opts=opts, typ=GetEgressMatrixCellDefaultResult)
    return __ret__.apply(lambda __response__: GetEgressMatrixCellDefaultResult(
        default_rule=pulumi.get(__response__, 'default_rule'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        matrix_cell_status=pulumi.get(__response__, 'matrix_cell_status'),
        sgacls=pulumi.get(__response__, 'sgacls')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .provider import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_ise.config as __config
    config = __config
    import pulumi_ise.deviceadmin as __deviceadmin
    deviceadmin = __deviceadmin
    import pulumi_ise.identitymanagement as __identitymanagement
    identitymanagement = __identitymanagement
    import pulumi_ise.network as __network
    network = __network
    import pulumi_ise.networkaccess as __networkaccess
    networkaccess = __networkaccess
    import pulumi_ise.system as __system
    system = __system
    import pulumi_ise.trustsec as __trustsec
    trustsec = __trustsec
else:
    config = _utilities.lazy_import('pulumi_ise.config')
    deviceadmin = _utilities.lazy_import('pulumi_ise.deviceadmin')
    identitymanagement = _utilities.lazy_import('pulumi_ise.identitymanagement')
    network = _utilities.lazy_import('pulumi_ise.network')
    networkaccess = _utilities.lazy_import('pulumi_ise.networkaccess')
    system = _utilities.lazy_import('pulumi_ise.system')
    trustsec = _utilities.lazy_import('pulumi_ise.trustsec')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "ise",
  "mod": "deviceadmin/allowedProtocolsTacacs",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/allowedProtocolsTacacs:AllowedProtocolsTacacs": "AllowedProtocolsTacacs"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authenticationRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authenticationRule:AuthenticationRule": "AuthenticationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authenticationRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authenticationRuleUpdateRank:AuthenticationRuleUpdateRank": "AuthenticationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationExceptionRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationExceptionRule:AuthorizationExceptionRule": "AuthorizationExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationExceptionRuleUpdateRank:AuthorizationExceptionRuleUpdateRank": "AuthorizationExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationGlobalExceptionRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationGlobalExceptionRule:AuthorizationGlobalExceptionRule": "AuthorizationGlobalExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationGlobalExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationGlobalExceptionRuleUpdateRank:AuthorizationGlobalExceptionRuleUpdateRank": "AuthorizationGlobalExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationRule",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/authorizationRuleUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank": "AuthorizationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/condition",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/condition:Condition": "Condition"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/policySet",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/policySet:PolicySet": "PolicySet"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/policySetUpdateRank",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/policySetUpdateRank:PolicySetUpdateRank": "PolicySetUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/tacacsCommandSet",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/tacacsCommandSet:TacacsCommandSet": "TacacsCommandSet"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/tacacsProfile",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/tacacsProfile:TacacsProfile": "TacacsProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "deviceadmin/timeAndDateCondition",
  "fqn": "pulumi_ise.deviceadmin",
  "classes": {
   "ise:deviceadmin/timeAndDateCondition:TimeAndDateCondition": "TimeAndDateCondition"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryAddGroups",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryAddGroups:ActiveDirectoryAddGroups": "ActiveDirectoryAddGroups"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryJoinDomainWithAllNodes",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryJoinDomainWithAllNodes:ActiveDirectoryJoinDomainWithAllNodes": "ActiveDirectoryJoinDomainWithAllNodes"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/activeDirectoryJoinPoint",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/activeDirectoryJoinPoint:ActiveDirectoryJoinPoint": "ActiveDirectoryJoinPoint"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/certificateAuthenticationProfile",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/certificateAuthenticationProfile:CertificateAuthenticationProfile": "CertificateAuthenticationProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/endpoint",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/endpoint:Endpoint": "Endpoint"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/endpointIdentityGroup",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/endpointIdentityGroup:EndpointIdentityGroup": "EndpointIdentityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/identitySourceSequence",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/identitySourceSequence:IdentitySourceSequence": "IdentitySourceSequence"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/internalUser",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/internalUser:InternalUser": "InternalUser"
  }
 },
 {
  "pkg": "ise",
  "mod": "identitymanagement/userIdentityGroup",
  "fqn": "pulumi_ise.identitymanagement",
  "classes": {
   "ise:identitymanagement/userIdentityGroup:UserIdentityGroup": "UserIdentityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "network/device",
  "fqn": "pulumi_ise.network",
  "classes": {
   "ise:network/device:Device": "Device"
  }
 },
 {
  "pkg": "ise",
  "mod": "network/deviceGroup",
  "fqn": "pulumi_ise.network",
  "classes": {
   "ise:network/deviceGroup:DeviceGroup": "DeviceGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/allowedProtocols",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/allowedProtocols:AllowedProtocols": "AllowedProtocols"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authenticationRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authenticationRule:AuthenticationRule": "AuthenticationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authenticationRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authenticationRuleUpdateRank:AuthenticationRuleUpdateRank": "AuthenticationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationExceptionRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationExceptionRule:AuthorizationExceptionRule": "AuthorizationExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationExceptionRuleUpdateRank:AuthorizationExceptionRuleUpdateRank": "AuthorizationExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationGlobalExceptionRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationGlobalExceptionRule:AuthorizationGlobalExceptionRule": "AuthorizationGlobalExceptionRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationGlobalExceptionRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationGlobalExceptionRuleUpdateRank:AuthorizationGlobalExceptionRuleUpdateRank": "AuthorizationGlobalExceptionRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationProfile",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationProfile:AuthorizationProfile": "AuthorizationProfile"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationRule",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationRule:AuthorizationRule": "AuthorizationRule"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/authorizationRuleUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/authorizationRuleUpdateRank:AuthorizationRuleUpdateRank": "AuthorizationRuleUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/condition",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/condition:Condition": "Condition"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/dictionary",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/dictionary:Dictionary": "Dictionary"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/downloadableAcl",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/downloadableAcl:DownloadableAcl": "DownloadableAcl"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/policySet",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/policySet:PolicySet": "PolicySet"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/policySetUpdateRank",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/policySetUpdateRank:PolicySetUpdateRank": "PolicySetUpdateRank"
  }
 },
 {
  "pkg": "ise",
  "mod": "networkaccess/timeAndDateCondition",
  "fqn": "pulumi_ise.networkaccess",
  "classes": {
   "ise:networkaccess/timeAndDateCondition:TimeAndDateCondition": "TimeAndDateCondition"
  }
 },
 {
  "pkg": "ise",
  "mod": "system/licenseTierState",
  "fqn": "pulumi_ise.system",
  "classes": {
   "ise:system/licenseTierState:LicenseTierState": "LicenseTierState"
  }
 },
 {
  "pkg": "ise",
  "mod": "system/repository",
  "fqn": "pulumi_ise.system",
  "classes": {
   "ise:system/repository:Repository": "Repository"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/egressMatrixCell",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/egressMatrixCell:EgressMatrixCell": "EgressMatrixCell"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/egressMatrixCellDefault",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/egressMatrixCellDefault:EgressMatrixCellDefault": "EgressMatrixCellDefault"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/ipToSgtMapping",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/ipToSgtMapping:IpToSgtMapping": "IpToSgtMapping"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/ipToSgtMappingGroup",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/ipToSgtMappingGroup:IpToSgtMappingGroup": "IpToSgtMappingGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/securityGroup",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/securityGroupAcl",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/securityGroupAcl:SecurityGroupAcl": "SecurityGroupAcl"
  }
 },
 {
  "pkg": "ise",
  "mod": "trustsec/sxpDomainFilter",
  "fqn": "pulumi_ise.trustsec",
  "classes": {
   "ise:trustsec/sxpDomainFilter:SxpDomainFilter": "SxpDomainFilter"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "ise",
  "token": "pulumi:providers:ise",
  "fqn": "pulumi_ise",
  "class": "Provider"
 }
]
"""
)



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['LicenseTierStateArgs', 'LicenseTierState']

@pulumi.input_type
class LicenseTierStateArgs:
    def __init__(__self__, *,
                 licenses: pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]):
        """
        The set of arguments for constructing a LicenseTierState resource.
        :param pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]] licenses: List of licenses
        """
        pulumi.set(__self__, "licenses", licenses)

    @property
    @pulumi.getter
    def licenses(self) -> pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]:
        """
        List of licenses
        """
        return pulumi.get(self, "licenses")

    @licenses.setter
    def licenses(self, value: pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]):
        pulumi.set(self, "licenses", value)


@pulumi.input_type
class _LicenseTierStateState:
    def __init__(__self__, *,
                 licenses: Optional[pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]] = None):
        """
        Input properties used for looking up and filtering LicenseTierState resources.
        :param pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]] licenses: List of licenses
        """
        if licenses is not None:
            pulumi.set(__self__, "licenses", licenses)

    @property
    @pulumi.getter
    def licenses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]]:
        """
        List of licenses
        """
        return pulumi.get(self, "licenses")

    @licenses.setter
    def licenses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['LicenseTierStateLicenseArgs']]]]):
        pulumi.set(self, "licenses", value)


class LicenseTierState(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 licenses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LicenseTierStateLicenseArgs', 'LicenseTierStateLicenseArgsDict']]]]] = None,
                 __props__=None):
        """
        This resource can manage a License Tier State.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.system.LicenseTierState("example", licenses=[{
            "name": "ESSENTIAL",
            "status": "ENABLED",
        }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:system/licenseTierState:LicenseTierState example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['LicenseTierStateLicenseArgs', 'LicenseTierStateLicenseArgsDict']]]] licenses: List of licenses
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LicenseTierStateArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource can manage a License Tier State.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ise as ise

        example = ise.system.LicenseTierState("example", licenses=[{
            "name": "ESSENTIAL",
            "status": "ENABLED",
        }])
        ```

        ## Import

        ```sh
        $ pulumi import ise:system/licenseTierState:LicenseTierState example "76d24097-41c4-4558-a4d0-a8c07ac08470"
        ```

        :param str resource_name: The name of the resource.
        :param LicenseTierStateArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LicenseTierStateArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 licenses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LicenseTierStateLicenseArgs', 'LicenseTierStateLicenseArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LicenseTierStateArgs.__new__(LicenseTierStateArgs)

            if licenses is None and not opts.urn:
                raise TypeError("Missing required property 'licenses'")
            __props__.__dict__["licenses"] = licenses
        super(LicenseTierState, __self__).__init__(
            'ise:system/licenseTierState:LicenseTierState',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            licenses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['LicenseTierStateLicenseArgs', 'LicenseTierStateLicenseArgsDict']]]]] = None) -> 'LicenseTierState':
        """
        Get an existing LicenseTierState resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['LicenseTierStateLicenseArgs', 'LicenseTierStateLicenseArgsDict']]]] licenses: List of licenses
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LicenseTierStateState.__new__(_LicenseTierStateState)

        __props__.__dict__["licenses"] = licenses
        return LicenseTierState(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def licenses(self) -> pulumi.Output[Sequence['outputs.LicenseTierStateLicense']]:
        """
        List of licenses
        """
        return pulumi.get(self, "licenses")

